@@ -51,6 +51,25 @@
 ;;:require 'browse-kill-ring
   :group 'emacs-goodies-el)
 
+;; color-theme
+(defgroup color-theme nil
+  "Color Themes for Emacs.
+A color theme consists of frame parameter settings, variable settings,
+and face definitions."
+  :version "20.6"
+  :group 'faces
+  :link '(custom-manual "(emacs-goodies-el)color-theme")
+  :load 'color-theme
+  :group 'emacs-goodies-el)
+
+;; csv-mode
+(defgroup CSV nil
+  "Major mode for editing files of comma-separated value type."
+  :group 'convenience
+  :link '(custom-manual "(emacs-goodies-el)csv-mode")
+  :load 'csv-mode
+  :group 'emacs-goodies-el)
+
 ;; ctypes
 (defgroup ctypes nil
   "Enhanced Font lock support for custom defined types."
@@ -59,6 +78,28 @@
   :load 'ctypes
   :group 'emacs-goodies-el)
 
+;; cua
+(defgroup CUA-mode nil
+  "Emulate CUA key bindings including C-x and C-c."
+  :prefix "CUA-mode"
+  :group 'editing-basics
+  :group 'convenience
+  :group 'emulations
+  :link '(emacs-commentary-link :tag "Commentary" "cua.el")
+  :link '(emacs-library-link :tag "Lisp File" "cua.el")
+  :link '(custom-manual "(emacs-goodies-el)cua")
+  :load 'cua
+  :group 'emacs-goodies-el)
+
+;; cwebm
+(defgroup CWEBm nil
+  "Major mode for editing CWEB and WEB programs"
+  :prefix "cwebm-"
+  :group 'languages
+  :link '(custom-manual "(emacs-goodies-el)cwebm")
+  :load 'cwebm
+  :group 'emacs-goodies-el)
+
 ;; df
 (defgroup df nil
   "Display space left on partitions in the mode-line."
@@ -201,6 +242,17 @@ selectable views (limits)."
   ;;:require 'ibuffer
     :group 'emacs-goodies-el))
 
+;; ido.el
+(defgroup ido nil
+  "Switch between files using substrings."
+  :group 'extensions
+  :group 'convenience
+  :link '(emacs-commentary-link :tag "Commentary" "ido.el")
+  :link '(emacs-library-link :tag "Lisp File" "ido.el")
+  :link '(custom-manual "(emacs-goodies-el)ido")
+  :load 'ido
+  :group 'emacs-goodies-el)
+
 ;; initsplit
 (defgroup initsplit nil
   "Code to split customizations into different files."
@@ -244,6 +296,23 @@ selectable views (limits)."
   :load 'lcomp
   :group 'emacs-goodies-el)
 
+;; maplev
+(defgroup maplev nil
+  "Major mode for editing Maple source in Emacs"
+  :group 'languages
+  :link '(custom-manual "(emacs-goodies-el)maplev")
+  :load 'maplev
+  :group 'emacs-goodies-el)
+
+;; matlab
+(defgroup matlab nil
+  "Matlab mode."
+  :prefix "matlab-"
+  :group 'languages
+  :link '(custom-manual "(emacs-goodies-el)matlab")
+  :load 'matlab
+  :group 'emacs-goodies-el)
+
 ;; minibuffer-complete-cycle
 (defgroup minibuffer-complete-cycle nil
   "Cycle through the *Completions* buffer."
@@ -363,6 +432,14 @@ effect.  Therefore it is recommended to `newsticker-stop' and then
   :load 'shell-command
   :group 'emacs-goodies-el)
 
+(defgroup slang nil
+  "Major mode for editing slang code."
+  :prefix "slang-"
+  :group 'languages
+  :link '(custom-manual "(emacs-goodies-el)slang-mode")
+  :load 'slang-mode
+  :group 'emacs-goodies-el)
+
 (defgroup silly-mail nil
   "Generate bozotic mail headers."
   :group 'mail
@@ -372,6 +449,13 @@ effect.  Therefore it is recommended to `newsticker-stop' and then
   :load 'silly-mail
   :group 'emacs-goodies-el)
 
+(defgroup tabbar nil
+  "Display a tab bar in the header line."
+  :group 'convenience
+  :link '(custom-manual "(emacs-goodies-el)tabbar")
+  :load 'tabbar
+  :group 'emacs-goodies-el)
+
 ;; table
 (defgroup table nil
   "Text based table manipulation utilities.
@@ -414,6 +498,14 @@ See `table-insert' for examples about how to use."
 ;;:require 'thinks
   :group 'emacs-goodies-el)
 
+;;tlc
+(defgroup tlc nil
+  "Major mode for editing tlc files."
+  :group 'languages
+  :link '(custom-manual "(emacs-goodies-el)tlc")
+  :load 'tlc
+  :group 'emacs-goodies-el)
+
 ;; todoo
 (when (not (featurep 'xemacs))
   (defgroup todoo nil
