@@ -20,20 +20,17 @@ Any changes made in that buffer will be propagated to this buffer." t nil)
 
 ;;;***
 
-;;;### (autoloads (apache-mode) "apache-mode" "apache-mode.el" (16391
-;;;;;;  1480))
+;;;### (autoloads (apache-mode) "apache-mode" "apache-mode.el" (17102
+;;;;;;  30750))
 ;;; Generated autoloads from apache-mode.el
 
 (autoload (quote apache-mode) "apache-mode" "\
-Major mode for editing Apache configuration files.
-
-\\{apache-mode-map}
-
-\\[apache-mode] runs the hook `apache-mode-hook'." t nil)
-(add-to-list 'auto-mode-alist '("\\.htaccess$"   . apache-mode))
-(add-to-list 'auto-mode-alist '("httpd\\.conf$"  . apache-mode))
-(add-to-list 'auto-mode-alist '("srm\\.conf$"    . apache-mode))
-(add-to-list 'auto-mode-alist '("access\\.conf$" . apache-mode))
+Major mode for editing Apache configuration files." t nil)
+(add-to-list 'auto-mode-alist '("\\.htaccess\\'"   . apache-mode))
+(add-to-list 'auto-mode-alist '("httpd\\.conf\\'"  . apache-mode))
+(add-to-list 'auto-mode-alist '("srm\\.conf\\'"    . apache-mode))
+(add-to-list 'auto-mode-alist '("access\\.conf\\'" . apache-mode))
+(add-to-list 'auto-mode-alist '("sites-\\(available\\|enabled\\)/" . apache-mode))
 
 ;;;***
 
@@ -61,7 +58,7 @@ Turn off ASCII code display." t nil)
 ;;;***
 
 ;;;### (autoloads (bar-cursor-change bar-cursor-mode) "bar-cursor"
-;;;;;;  "bar-cursor.el" (16391 1480))
+;;;;;;  "bar-cursor.el" (17246 57581))
 ;;; Generated autoloads from bar-cursor.el
 
 (autoload (quote bar-cursor-mode) "bar-cursor" "\
@@ -79,11 +76,11 @@ Enable or disable advice based on value of variable `bar-cursor-mode'." nil nil)
 
 ;;;### (autoloads (boxquote-unbox boxquote-unbox-region boxquote-fill-paragraph
 ;;;;;;  boxquote-kill boxquote-narrow-to-boxquote-content boxquote-narrow-to-boxquote
-;;;;;;  boxquote-text boxquote-shell-command boxquote-describe-key
+;;;;;;  boxquote-text boxquote-where-is boxquote-shell-command boxquote-describe-key
 ;;;;;;  boxquote-describe-variable boxquote-describe-function boxquote-boxquote
 ;;;;;;  boxquote-paragraph boxquote-defun boxquote-yank boxquote-kill-ring-save
 ;;;;;;  boxquote-insert-file boxquote-buffer boxquote-region boxquote-title)
-;;;;;;  "boxquote" "boxquote.el" (16259 18879))
+;;;;;;  "boxquote" "boxquote.el" (17245 26633))
 ;;; Generated autoloads from boxquote.el
 
 (autoload (quote boxquote-title) "boxquote" "\
@@ -133,11 +130,17 @@ Call `describe-function' and boxquote the output into the current buffer." t nil
 Call `describe-variable' and boxquote the output into the current buffer." t nil)
 
 (autoload (quote boxquote-describe-key) "boxquote" "\
-Call `describe-key' and boxquote the output into the current buffer." t nil)
+Call `describe-key' and boxquote the output into the current buffer.
+
+If the call to this command is prefixed with \\[universal-argument] you will also be
+prompted for a buffer. The key defintion used will be taken from that buffer." t nil)
 
 (autoload (quote boxquote-shell-command) "boxquote" "\
 Call `shell-command' with COMMAND and boxquote the output." t nil)
 
+(autoload (quote boxquote-where-is) "boxquote" "\
+Call `where-is' with DEFINITION and boxquote the result." t nil)
+
 (autoload (quote boxquote-text) "boxquote" "\
 Insert TEXT, boxquoted." t nil)
 
@@ -179,7 +182,7 @@ This requires the value of `shell-file-name' to support redirection using \">\".
 ;;;***
 
 ;;;### (autoloads (browse-kill-ring browse-kill-ring-default-keybindings)
-;;;;;;  "browse-kill-ring" "browse-kill-ring.el" (16391 1480))
+;;;;;;  "browse-kill-ring" "browse-kill-ring.el" (17246 57581))
 ;;; Generated autoloads from browse-kill-ring.el
 
 (autoload (quote browse-kill-ring-default-keybindings) "browse-kill-ring" "\
@@ -191,11 +194,45 @@ behavior.  This function sets things up so that M-y will invoke
 (autoload (quote browse-kill-ring) "browse-kill-ring" "\
 Display items in the `kill-ring' in another buffer." t nil)
 
+;;;***
+
+;;;### (autoloads (cfengine-mode) "cfengine" "cfengine.el" (17213
+;;;;;;  19161))
+;;; Generated autoloads from cfengine.el
+
+(autoload (quote cfengine-mode) "cfengine" "\
+Cfengine mode is the major mode for editing Cfengine code.
+
+Bindings are as follows:
+
+ Indent line                                          '\\[cfengine-tab]'
+ Indent line, insert newline and indent the new line. '\\[newline-and-indent]'
+
+Comments are handled using standard Emacs conventions, including:
+ Start a comment                                      '\\[indent-for-comment]'
+ Comment region                                       '\\[comment-region]'
+ Uncomment region                                     '\\[cfengine-uncomment-region]'
+ Continue comment on next line                        '\\[indent-new-comment-line]'
+" t nil)
+
+;;;***
+
+;;;### (autoloads (color-theme-select) "color-theme" "color-theme.el"
+;;;;;;  (17246 57581))
+;;; Generated autoloads from color-theme.el
+
+(autoload (quote color-theme-select) "color-theme" "\
+Displays a special buffer for selecting and installing a color theme.
+With optional prefix ARG, this buffer will include color theme libraries
+as well.  A color theme library is in itself not complete, it must be
+used as part of another color theme to be useful.  Thus, color theme
+libraries are mainly useful for color theme authors." t nil)
+
 ;;;***
 
 ;;;### (autoloads (ctypes-read-file ctypes-auto-parse-mode ctypes-file
 ;;;;;;  ctypes-dir ctypes-tags ctypes-all-buffers ctypes-buffer ctypes-define-type-in-mode
-;;;;;;  ctypes-define-type) "ctypes" "ctypes.el" (16391 1480))
+;;;;;;  ctypes-define-type) "ctypes" "ctypes.el" (17246 57581))
 ;;; Generated autoloads from ctypes.el
 
 (autoload (quote ctypes-define-type) "ctypes" "\
@@ -287,8 +324,95 @@ Return non-nil if new types are found." t nil)
 
 ;;;***
 
-;;;### (autoloads (dedicated-mode) "dedicated" "dedicated.el" (16391
-;;;;;;  1480))
+;;;### (autoloads (CUA-keypad-mode CUA-mode-on CUA-mode CUA-mode-bindings
+;;;;;;  CUA-movement-key CUA-exchange-point-and-mark CUA-mode) "cua"
+;;;;;;  "cua.el" (17212 38105))
+;;; Generated autoloads from cua.el
+
+(defvar CUA-mode nil "\
+Non-nil means that CUA emulation mode is enabled.
+In CUA mode, shifted movement keys highlight and extend the region.
+When a region is highlighted, the binding of the C-x and C-c keys are
+temporarily changed to work as Motif, MAC or MS-Windows cut and paste.
+Also, insertion commands first delete the region and then insert.
+This mode enables Transient Mark mode and it provides a superset of the
+PC Selection Mode and Delete Selection Modes.
+
+Setting this variable directly does not take effect;
+use either \\[customize] or the function `CUA-mode'.")
+
+(custom-add-to-group (quote CUA-mode) (quote CUA-mode) (quote custom-variable))
+
+(custom-add-load (quote CUA-mode) (quote cua))
+
+(autoload (quote CUA-exchange-point-and-mark) "cua" "\
+Exchanges point and mark, but don't activate the mark.
+Activates the mark if a prefix argument is given." t nil)
+
+(autoload (quote CUA-movement-key) "cua" "\
+Like `global-set-key' but also binds shifted KEY to COMMAND.
+KEY should be a simple symbol or character, like home or ?\\C-e,
+or a list like (control home)." nil nil)
+
+(autoload (quote CUA-mode-bindings) "cua" "\
+Define even more compatibility bindings.
+Optional argument BIND identifies what bindings to add." nil nil)
+
+(autoload (quote CUA-mode) "cua" "\
+Toggle CUA keybinding mode.
+When ON, C-x and C-c will cut and copy the selection if the selection
+is active (i.e. the region is highlighted), and typed text replaces
+the active selection. When OFF, typed text is just inserted at point.
+If non-nil, the optional second argument EXTRA specifies additional
+key bindings as defined by CUA-mode-bindings.
+The following key bindings are made unless optional third argument 
+NOBIND is non-nil:
+ C-z  is undo
+ C-v  is yank
+ C-x C-x is CUA-exchange-point-and-mark which doesn't enable the mark
+ C-space   starts/cancels the normal region 
+ S-C-space sets/cancels the global marker
+ S-return  starts a rectangular region, if repeated toggles between
+          rectangle and normal region." t nil)
+
+(autoload (quote CUA-mode-on) "cua" nil t nil)
+
+(autoload (quote CUA-keypad-mode) "cua" "\
+Set keypad bindings in function-key-map according to MODE.
+If optional second argument NUMLOCK is non-nil, the NumLock On bindings
+are changed. Otherwise, the NumLock Off binding are changed.
+
+ Mode      Binding
+ -------------------------------------------------------------
+ 'prefix   Command prefix argument, i.e.  M-0 .. M-9 and M--
+ 'S-cursor Bind shifted keypad keys to the shifted cursor movement keys.
+ 'cursor   Bind keypad keys to the cursor movement keys.
+ 'numeric  Plain numeric, i.e. 0 .. 9 and .  (or DECIMAL arg)
+ 'none     Removes all bindings for keypad keys in function-key-map.
+
+If mode is 'numeric and the optional third argument DECIMAL is non-nil,
+the decimal key on the keypad i<s mapped to DECIMAL instead of [.]." nil nil)
+
+;;;***
+
+;;;### (autoloads (cwebm-mode webm-mode) "cwebm" "cwebm.el" (17221
+;;;;;;  28087))
+;;; Generated autoloads from cwebm.el
+
+(autoload (quote webm-mode) "cwebm" "\
+Major mode like TeX mode plus \\[forward-module] and \\[backward-module].
+Used for relative module movement. The automatic \" feature is disabled." t nil)
+
+(autoload (quote cwebm-mode) "cwebm" "\
+Major mode like LaTeX mode plus \\[forward-module] and \\[backward-module].
+Used for relative module movement. The automatic \" feature is disabled." t nil)
+(setq auto-mode-alist (cons '("\\.w$" . cwebm-mode) auto-mode-alist))
+(setq auto-mode-alist (cons '("\\.ch$" . cwebm-mode) auto-mode-alist))
+
+;;;***
+
+;;;### (autoloads (dedicated-mode) "dedicated" "dedicated.el" (17246
+;;;;;;  57581))
 ;;; Generated autoloads from dedicated.el
 
 (autoload (quote dedicated-mode) "dedicated" "\
@@ -307,7 +431,7 @@ This display updates automatically every `df-refresh' seconds." t nil)
 ;;;***
 
 ;;;### (autoloads (diminished-modes diminish-undo diminish) "diminish"
-;;;;;;  "diminish.el" (16391 1480))
+;;;;;;  "diminish.el" (17246 57581))
 ;;; Generated autoloads from diminish.el
 
 (autoload (quote diminish) "diminish" "\
@@ -352,7 +476,7 @@ what diminished modes would be on the mode-line if they were still minor." t nil
 
 ;;;***
 
-;;;### (autoloads (edit-env) "edit-env" "edit-env.el" (16391 1481))
+;;;### (autoloads (edit-env) "edit-env" "edit-env.el" (17246 57581))
 ;;; Generated autoloads from edit-env.el
 
 (autoload (quote edit-env) "edit-env" "\
@@ -380,8 +504,8 @@ Update ``egocentric-regexp-list'' from $USER and $NAME variables." t nil)
 
 ;;;***
 
-;;;### (autoloads (ff-paths-install) "ff-paths" "ff-paths.el" (16318
-;;;;;;  50276))
+;;;### (autoloads (ff-paths-install) "ff-paths" "ff-paths.el" (17194
+;;;;;;  6223))
 ;;; Generated autoloads from ff-paths.el
 
 (autoload (quote ff-paths-install) "ff-paths" "\
@@ -401,8 +525,8 @@ Toggle floatbg mode" t nil)
 ;;;;;;  folding-mode-add-find-file-hook folding-keep-hooked folding-install-hooks
 ;;;;;;  folding-uninstall-hooks folding-mode-hook-no-regexp folding-mode-string
 ;;;;;;  folding-inside-mode-name folding-default-mouse-keys-function
-;;;;;;  folding-default-keys-function) "folding" "folding.el" (16313
-;;;;;;  9500))
+;;;;;;  folding-default-keys-function) "folding" "folding.el" (16806
+;;;;;;  38694))
 ;;; Generated autoloads from folding.el
 
 (defvar folding-mode nil "\
@@ -451,7 +575,7 @@ of \"{{{ \" and \"}}}\" are used.
 Use function  `folding-add-to-marks-list' to add more fold marks. The function
 also explains the alist use in details.
 
-Use function `folding-set-local-variables' is you change the current mode's
+Use function `folding-set-local-variables' if you change the current mode's
 folding marks during the session.")
 
 (autoload (quote folding-uninstall-hooks) "folding" "\
@@ -585,7 +709,7 @@ Managing folds
     of blank lines between the fold marks and the contents of the fold is
     set to 1 (by default).
 
-Folding package customisations
+Folding package customizations
 
     If the fold marks are not set on entry to Folding mode, they are set to
     a default for current major mode, as defined by
@@ -639,7 +763,7 @@ typing the keymap prefix (default F2).
 ;;;***
 
 ;;;### (autoloads (highlight-beyond-fill-column) "highlight-beyond-fill-column"
-;;;;;;  "highlight-beyond-fill-column.el" (16391 1480))
+;;;;;;  "highlight-beyond-fill-column.el" (17246 57581))
 ;;; Generated autoloads from highlight-beyond-fill-column.el
 
 (autoload (quote highlight-beyond-fill-column) "highlight-beyond-fill-column" "\
@@ -660,7 +784,7 @@ line is hightlighted by customizing the group highlight-current-line." t nil)
 ;;;***
 
 ;;;### (autoloads (home-end-end home-end-home) "home-end" "home-end.el"
-;;;;;;  (16391 1480))
+;;;;;;  (17246 57581))
 ;;; Generated autoloads from home-end.el
 
 (autoload (quote home-end-home) "home-end" "\
@@ -676,8 +800,8 @@ of window, third in a row goes to end of buffer." t nil)
 ;;;***
 
 ;;;### (autoloads (htmlize-many-files-dired htmlize-many-files htmlize-file
-;;;;;;  htmlize-region htmlize-buffer) "htmlize" "htmlize.el" (16284
-;;;;;;  31796))
+;;;;;;  htmlize-region htmlize-buffer) "htmlize" "htmlize.el" (16285
+;;;;;;  9287))
 ;;; Generated autoloads from htmlize.el
 
 (autoload (quote htmlize-buffer) "htmlize" "\
@@ -752,10 +876,218 @@ to \"*Ibuffer*\".
 Optional argument QUALIFIERS is an initial set of limiting qualifiers
 to use; see `ibuffer-limiting-qualifiers'." t nil)
 
+;;;***
+
+;;;### (autoloads (ido-read-directory-name ido-read-file-name ido-dired
+;;;;;;  ido-insert-file ido-write-file ido-find-file-other-frame
+;;;;;;  ido-display-file ido-find-file-read-only-other-frame ido-find-file-read-only-other-window
+;;;;;;  ido-find-file-read-only ido-find-alternate-file ido-find-file-other-window
+;;;;;;  ido-find-file ido-find-file-in-dir ido-switch-buffer-other-frame
+;;;;;;  ido-insert-buffer ido-kill-buffer ido-display-buffer ido-switch-buffer-other-window
+;;;;;;  ido-switch-buffer ido-read-buffer ido-mode ido-enabled) "ido"
+;;;;;;  "ido.el" (17213 20908))
+;;; Generated autoloads from ido.el
+
+(defvar ido-enabled nil "\
+Determines for which functional group (buffer and files) ido behavior
+should be enabled. The following values are possible:
+- 'buffer: Turn only on ido buffer behavior (switching, killing,
+  displaying...) 
+- 'file: Turn only on ido file behavior (finding, writing, inserting...)
+- 'both: Turn on ido buffer and file behavior.
+- nil: Turn off any ido switching.
+
+Setting this variable directly does not take effect;
+use either \\[customize] or the function `ido-mode'.")
+
+(custom-add-to-group (quote ido) (quote ido-enabled) (quote custom-variable))
+
+(custom-add-load (quote ido-enabled) (quote ido))
+
+(autoload (quote ido-mode) "ido" "\
+Toggle ido speed-ups on or off.
+With ARG, turn ido speed-up on if arg is positive, off otherwise.
+If second argument NOBIND is non-nil, no keys are rebound; otherwise,
+turning on ido-mode will modify the default keybindings for the 
+find-file and switch-to-buffer families of commands to the ido
+versions of these functions.
+However, if second arg equals 'files, bind only for files, or if it 
+equals 'buffers, bind only for buffers.
+This function also adds a hook to the minibuffer." t nil)
+
+(autoload (quote ido-read-buffer) "ido" "\
+Replacement for the built-in `read-buffer'.
+Return the name of a buffer selected.  
+PROMPT is the prompt to give to the user.  DEFAULT if given is the default
+buffer to be selected, which will go to the front of the list.
+If REQUIRE-MATCH is non-nil, an existing-buffer must be selected.
+If INITIAL is non-nil, it specifies the initial input string." nil nil)
+
+(autoload (quote ido-switch-buffer) "ido" "\
+Switch to another buffer.
+The buffer is displayed according to `ido-default-buffer-method' -- the
+default is to show it in the same window, unless it is already visible
+in another frame.
+
+As you type in a string, all of the buffers matching the string are
+displayed if substring-matching is used (default). Look at
+`ido-enable-prefix' and `ido-toggle-prefix'. When you have found the
+buffer you want, it can then be selected. As you type, most keys have their
+normal keybindings, except for the following: \\<ido-mode-map>
+
+RET Select the buffer at the front of the list of matches.  If the
+list is empty, possibly prompt to create new buffer.
+
+\\[ido-select-text] Select the current prompt as the buffer.
+If no buffer is found, prompt for a new one.
+
+\\[ido-next-match] Put the first element at the end of the list.
+\\[ido-prev-match] Put the last element at the start of the list.
+\\[ido-complete] Complete a common suffix to the current string that 
+matches all buffers.  If there is only one match, select that buffer.
+If there is no common suffix, show a list of all matching buffers
+in a separate window.
+\\[ido-edit-input] Edit input string.
+\\[ido-fallback-command] Fallback to non-ido version of current command.
+\\[ido-toggle-regexp] Toggle regexp searching.
+\\[ido-toggle-prefix] Toggle between substring and prefix matching.
+\\[ido-toggle-case] Toggle case-sensitive searching of buffer names.
+\\[ido-completion-help] Show list of matching buffers in separate window.
+\\[ido-enter-find-file] Drop into ido-find-file.
+\\[ido-kill-buffer-at-head] Kill buffer at head of buffer list.
+\\[ido-toggle-ignore] Toggle ignoring buffers listed in `ido-ignore-buffers'." t nil)
+
+(autoload (quote ido-switch-buffer-other-window) "ido" "\
+Switch to another buffer and show it in another window.
+The buffer name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido'." t nil)
+
+(autoload (quote ido-display-buffer) "ido" "\
+Display a buffer in another window but don't select it.
+The buffer name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido'." t nil)
+
+(autoload (quote ido-kill-buffer) "ido" "\
+Kill a buffer.
+The buffer name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido'." t nil)
+
+(autoload (quote ido-insert-buffer) "ido" "\
+Insert contents of a buffer in current buffer after point.
+The buffer name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido'." t nil)
+
+(autoload (quote ido-switch-buffer-other-frame) "ido" "\
+Switch to another buffer and show it in another frame.
+The buffer name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido'." t nil)
+
+(autoload (quote ido-find-file-in-dir) "ido" "\
+Switch to another file starting from DIR." t nil)
+
+(autoload (quote ido-find-file) "ido" "\
+Edit file with name obtained via minibuffer.
+The file is displayed according to `ido-default-file-method' -- the
+default is to show it in the same window, unless it is already
+visible in another frame.
+
+The file name is selected interactively by typing a substring. As you type
+in a string, all of the filenames matching the string are displayed if
+substring-matching is used (default). Look at `ido-enable-prefix' and
+`ido-toggle-prefix'. When you have found the filename you want, it can
+then be selected. As you type, most keys have their normal keybindings,
+except for the following: \\<ido-mode-map>
+
+RET Select the file at the front of the list of matches.  If the
+list is empty, possibly prompt to create new file.
+
+\\[ido-select-text] Select the current prompt as the buffer or file.
+If no buffer or file is found, prompt for a new one.
+
+\\[ido-next-match] Put the first element at the end of the list.
+\\[ido-prev-match] Put the last element at the start of the list.
+\\[ido-complete] Complete a common suffix to the current string that 
+matches all files.  If there is only one match, select that file.
+If there is no common suffix, show a list of all matching files
+in a separate window.
+\\[ido-edit-input] Edit input string (including path).
+\\[ido-prev-work-directory] or \\[ido-next-work-directory] go to previous/next directory in work directory history.
+\\[ido-merge-work-directories] search for file in the work directory history.
+\\[ido-forget-work-directory] removes current directory from the work directory history.
+\\[ido-prev-work-file] or \\[ido-next-work-file] cycle through the work file history.
+\\[ido-wide-find-file] and \\[ido-wide-find-dir] prompts and uses find to locate files or directories.
+\\[ido-make-directory] prompts for a directory to create in current directory.
+\\[ido-fallback-command] Fallback to non-ido version of current command.
+\\[ido-toggle-regexp] Toggle regexp searching.
+\\[ido-toggle-prefix] Toggle between substring and prefix matching.
+\\[ido-toggle-case] Toggle case-sensitive searching of file names.
+\\[ido-toggle-vc] Toggle version control for this file.
+\\[ido-toggle-literal] Toggle literal reading of this file.
+\\[ido-completion-help] Show list of matching files in separate window.
+\\[ido-toggle-ignore] Toggle ignoring files listed in `ido-ignore-files'." t nil)
+
+(autoload (quote ido-find-file-other-window) "ido" "\
+Switch to another file and show it in another window.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-find-alternate-file) "ido" "\
+Switch to another file and show it in another window.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-find-file-read-only) "ido" "\
+Edit file read-only with name obtained via minibuffer.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-find-file-read-only-other-window) "ido" "\
+Edit file read-only in other window with name obtained via minibuffer.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-find-file-read-only-other-frame) "ido" "\
+Edit file read-only in other frame with name obtained via minibuffer.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-display-file) "ido" "\
+Display a file in another window but don't select it.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-find-file-other-frame) "ido" "\
+Switch to another file and show it in another frame.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-write-file) "ido" "\
+Write current buffer to a file.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-insert-file) "ido" "\
+Insert contents of file in current buffer.
+The file name is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-dired) "ido" "\
+Call dired the ido way.
+The directory is selected interactively by typing a substring.
+For details of keybindings, do `\\[describe-function] ido-find-file'." t nil)
+
+(autoload (quote ido-read-file-name) "ido" "\
+Read file name, prompting with PROMPT and completing in directory DIR.
+See `read-file-name' for additional parameters." nil nil)
+
+(autoload (quote ido-read-directory-name) "ido" "\
+Read directory name, prompting with PROMPT and completing in directory DIR.
+See `read-file-name' for additional parameters." nil nil)
+
 ;;;***
 
 ;;;### (autoloads (joc-toggle-buffer) "joc-toggle-buffer" "joc-toggle-buffer.el"
-;;;;;;  (16391 1481))
+;;;;;;  (17246 57581))
 ;;; Generated autoloads from joc-toggle-buffer.el
 
 (autoload (quote joc-toggle-buffer) "joc-toggle-buffer" "\
@@ -765,7 +1097,7 @@ Switch to previous active buffer." t nil)
 
 ;;;### (autoloads (joc-toggle-case-by-region joc-toggle-case-by-word-backwards
 ;;;;;;  joc-toggle-case-by-word joc-toggle-case-backwards joc-toggle-case)
-;;;;;;  "joc-toggle-case" "joc-toggle-case.el" (16391 1481))
+;;;;;;  "joc-toggle-case" "joc-toggle-case.el" (17246 57581))
 ;;; Generated autoloads from joc-toggle-case.el
 
 (autoload (quote joc-toggle-case) "joc-toggle-case" "\
@@ -829,8 +1161,8 @@ the name of the mode-map that goes with the given mode." nil (quote macro))
 
 ;;;***
 
-;;;### (autoloads (lcomp-activate-advices) "lcomp" "lcomp.el" (16391
-;;;;;;  1481))
+;;;### (autoloads (lcomp-activate-advices) "lcomp" "lcomp.el" (17246
+;;;;;;  57581))
 ;;; Generated autoloads from lcomp.el
 
 (autoload (quote lcomp-activate-advices) "lcomp" "\
@@ -839,8 +1171,8 @@ Activate lcomp advices if ON is non-nil, disable otherwise." t nil)
 ;;;***
 
 ;;;### (autoloads (marker-visit-truncate-mark-ring marker-visit-next
-;;;;;;  marker-visit-prev) "marker-visit" "marker-visit.el" (16391
-;;;;;;  1481))
+;;;;;;  marker-visit-prev) "marker-visit" "marker-visit.el" (17246
+;;;;;;  57581))
 ;;; Generated autoloads from marker-visit.el
 
 (autoload (quote marker-visit-prev) "marker-visit" "\
@@ -854,8 +1186,74 @@ Truncate the `mark-ring'." t nil)
 
 ;;;***
 
-;;;### (autoloads (muttrc-mode) "muttrc-mode" "muttrc-mode.el" (16391
-;;;;;;  1480))
+;;;### (autoloads (matlab-shell matlab-mode) "matlab" "matlab.el"
+;;;;;;  (17238 24754))
+;;; Generated autoloads from matlab.el
+
+(autoload (quote matlab-mode) "matlab" "\
+MATLAB-mode is a major mode for editing MATLAB dot-m files.
+\\<matlab-mode-map>
+Convenient editing commands are:
+ \\[matlab-comment-region]   - Comment/Uncomment out a region of code.
+ \\[matlab-fill-comment-line] - Fill the current comment line.
+ \\[matlab-fill-region] - Fill code and comments in region.
+ \\[matlab-fill-paragraph]     - Refill the current command or comment.
+ \\[matlab-complete-symbol]   - Symbol completion of matlab symbolsbased on the local syntax.
+ \\[matlat-indent-sexp] - Indent syntactic block of code.
+
+Convenient navigation commands are:
+ \\[matlab-beginning-of-command]   - Move to the beginning of a command.
+ \\[matlab-end-of-command]   - Move to the end of a command.
+ \\[matlab-beginning-of-defun] - Move to the beginning of a function.
+ \\[matlab-end-of-defun] - Move do the end of a function.
+ \\[matlab-forward-sexp] - Move forward over a syntactic block of code.
+ \\[matlab-backward-sexp] - Move backwards over a syntactic block of code.
+
+Convenient template insertion commands:
+ \\[tempo-template-matlab-function] - Insert a function definition.
+ \\[tempo-template-matlab-if] - Insert an IF END block.
+ \\[tempo-template-matlab-for] - Insert a FOR END block.
+ \\[tempo-template-matlab-switch] - Insert a SWITCH END statement.
+ \\[matlab-insert-next-case] - Insert the next CASE condition in a SWITCH.
+ \\[matlab-insert-end-block] - Insert a matched END statement.  With optional ARG, reindent.
+ \\[matlab-stringify-region] - Convert plaintext in region to a string with correctly quoted chars.
+
+Variables:
+  `matlab-indent-level'		Level to indent blocks.
+  `matlab-cont-level'		Level to indent continuation lines.
+  `matlab-cont-requires-ellipsis' Does your MATLAB support implied elipsis.
+  `matlab-case-level'		Level to unindent case statements.
+  `matlab-indent-past-arg1-functions'
+                                Regexp of functions to indent past the first
+                                  argument on continuation lines.
+  `matlab-maximum-indents'      List of maximum indents during lineups.
+  `matlab-comment-column'       Goal column for on-line comments.
+  `fill-column'			Column used in auto-fill.
+  `matlab-indent-function-body' If non-nil, indents body of MATLAB functions.
+  `matlab-functions-have-end'	If non-nil, MATLAB functions terminate with end.
+  `matlab-return-function'	Customize RET handling with this function.
+  `matlab-auto-fill'            Non-nil, do auto-fill at startup.
+  `matlab-fill-code'            Non-nil, auto-fill code.
+  `matlab-fill-strings'         Non-nil, auto-fill strings.
+  `matlab-verify-on-save-flag'  Non-nil, enable code checks on save.
+  `matlab-highlight-block-match-flag'
+                                Enable matching block begin/end keywords.
+  `matlab-vers-on-startup'	If t, show version on start-up.
+  `matlab-handle-simulink'      If t, enable simulink keyword highlighting.
+
+All Key Bindings:
+\\{matlab-mode-map}" t nil)
+
+(autoload (quote matlab-shell) "matlab" "\
+Create a buffer with MATLAB running as a subprocess.
+
+MATLAB shell cannot work on the MS Windows platform because MATLAB is not
+a console application." t nil)
+
+;;;***
+
+;;;### (autoloads (muttrc-mode) "muttrc-mode" "muttrc-mode.el" (17246
+;;;;;;  57581))
 ;;; Generated autoloads from muttrc-mode.el
 
 (autoload (quote muttrc-mode) "muttrc-mode" "\
@@ -868,14 +1266,15 @@ This function ends by invoking the function(s) `muttrc-mode-hook'.
 ;;;***
 
 ;;;### (autoloads (newsticker-show-news newsticker-start) "newsticker"
-;;;;;;  "newsticker.el" (16391 1481))
+;;;;;;  "newsticker.el" (17246 57581))
 ;;; Generated autoloads from newsticker.el
 
 (autoload (quote newsticker-start) "newsticker" "\
 Start the newsticker.
 Start the timers for display and retrieval.  If the newsticker, i.e. the
 timers, are running already a warning message is printed unless
-DO-NOT-COMPLAIN-IF-RUNNING is not nil." t nil)
+DO-NOT-COMPLAIN-IF-RUNNING is not nil.
+Run `newsticker-start-hook' if newsticker was not running already." t nil)
 
 (autoload (quote newsticker-show-news) "newsticker" "\
 Switch to newsticker buffer.  You may want to bind this to a key." t nil)
@@ -883,7 +1282,7 @@ Switch to newsticker buffer.  You may want to bind this to a key." t nil)
 ;;;***
 
 ;;;### (autoloads (nuke-trailing-whitespace) "nuke-trailing-whitespace"
-;;;;;;  "nuke-trailing-whitespace.el" (16391 1480))
+;;;;;;  "nuke-trailing-whitespace.el" (17246 57581))
 ;;; Generated autoloads from nuke-trailing-whitespace.el
 
 (autoload (quote nuke-trailing-whitespace) "nuke-trailing-whitespace" "\
@@ -936,7 +1335,7 @@ displayed in the echo area if `pack-windows-verbose' is non-nil." t nil)
 ;;;***
 
 ;;;### (autoloads (perldoc-perl-hook perldoc-at-point perldoc) "perldoc"
-;;;;;;  "perldoc.el" (16391 1481))
+;;;;;;  "perldoc.el" (17246 57581))
 ;;; Generated autoloads from perldoc.el
 
 (autoload (quote perldoc) "perldoc" "\
@@ -952,7 +1351,7 @@ A hook which binds F1 to `perldoc-at-point'." nil nil)
 
 ;;;***
 
-;;;### (autoloads (project-add) "projects" "projects.el" (16391 1481))
+;;;### (autoloads (project-add) "projects" "projects.el" (17246 57581))
 ;;; Generated autoloads from projects.el
 
 (autoload (quote project-add) "projects" "\
@@ -961,7 +1360,7 @@ Add the project named NAME with root directory DIRECTORY." t nil)
 ;;;***
 
 ;;;### (autoloads (protect-process-buffer-from-kill-mode protect-buffer-from-kill-mode)
-;;;;;;  "protbuf" "protbuf.el" (16391 1481))
+;;;;;;  "protbuf" "protbuf.el" (17246 57581))
 ;;; Generated autoloads from protbuf.el
 
 (defvar protect-buffer-from-kill-mode nil "\
@@ -1036,7 +1435,7 @@ Clear the services \"cache\"." t nil)
 ;;;***
 
 ;;;### (autoloads (turn-on-setnu-mode setnu-mode) "setnu" "setnu.el"
-;;;;;;  (16391 1481))
+;;;;;;  (17246 57581))
 ;;; Generated autoloads from setnu.el
 
 (autoload (quote setnu-mode) "setnu" "\
@@ -1054,16 +1453,19 @@ to automatically turn on line numbering when enterting `text-mode'." nil nil)
 
 ;;;***
 
-;;;### (autoloads (shell-command-activate-advices) "shell-command"
-;;;;;;  "shell-command.el" (16313 9500))
+;;;### (autoloads (shell-command-completion-mode) "shell-command"
+;;;;;;  "shell-command.el" (17221 28092))
 ;;; Generated autoloads from shell-command.el
 
-(autoload (quote shell-command-activate-advices) "shell-command" nil nil nil)
+(autoload (quote shell-command-completion-mode) "shell-command" "\
+Enable or disable tab-completion for some commands.
+The commands are `shell-command', `shell-command-on-region', `grep',
+`grep-find' and `compile'." t nil)
 
 ;;;***
 
 ;;;### (autoloads (sm-add-all-headers sm-add-random-header) "silly-mail"
-;;;;;;  "silly-mail.el" (16391 1481))
+;;;;;;  "silly-mail.el" (17246 57581))
 ;;; Generated autoloads from silly-mail.el
 
 (autoload (quote sm-add-random-header) "silly-mail" "\
@@ -1075,6 +1477,18 @@ If a random header was already inserted, it it removed in favor of a new one." t
 Insert one of every kind of silly mail header defined.
 The choice of available headers is taken from `sm-mail-header-table'." t nil)
 
+;;;***
+
+;;;### (autoloads (slang-mode) "slang-mode" "slang-mode.el" (17211
+;;;;;;  12498))
+;;; Generated autoloads from slang-mode.el
+
+(autoload (quote slang-mode) "slang-mode" "\
+Major mode for editing slang scripts.
+The following keys are bound:
+\\{slang-mode-map}
+" t nil)
+
 ;;;***
 
 ;;;### (autoloads (sys-apropos) "sys-apropos" "sys-apropos.el" (16259
@@ -1084,6 +1498,58 @@ The choice of available headers is taken from `sm-mail-header-table'." t nil)
 (autoload (quote sys-apropos) "sys-apropos" "\
 Ask the system apropos command for man-pages matching QUERY." t nil)
 
+;;;***
+
+;;;### (autoloads (tabbar-local-mode tabbar-mode tabbar-forward-tab
+;;;;;;  tabbar-backward-tab tabbar-forward-group tabbar-backward-group
+;;;;;;  tabbar-forward tabbar-backward) "tabbar" "tabbar.el" (17212
+;;;;;;  38105))
+;;; Generated autoloads from tabbar.el
+
+(autoload (quote tabbar-backward) "tabbar" "\
+Select the previous available tab.
+Depend on the setting of the option `tabbar-cycling-scope'." t nil)
+
+(autoload (quote tabbar-forward) "tabbar" "\
+Select the next available tab.
+Depend on the setting of the option `tabbar-cycling-scope'." t nil)
+
+(autoload (quote tabbar-backward-group) "tabbar" "\
+Go to selected tab in the previous available group." t nil)
+
+(autoload (quote tabbar-forward-group) "tabbar" "\
+Go to selected tab in the next available group." t nil)
+
+(autoload (quote tabbar-backward-tab) "tabbar" "\
+Select the previous visible tab." t nil)
+
+(autoload (quote tabbar-forward-tab) "tabbar" "\
+Select the next visible tab." t nil)
+
+(defvar tabbar-mode nil "\
+Non-nil if Tabbar mode is enabled.
+See the command `tabbar-mode' for a description of this minor-mode.
+Setting this variable directly does not take effect;
+use either \\[customize] or the function `tabbar-mode'.")
+
+(custom-add-to-group (quote tabbar) (quote tabbar-mode) (quote custom-variable))
+
+(custom-add-load (quote tabbar-mode) (quote tabbar))
+
+(autoload (quote tabbar-mode) "tabbar" "\
+Toggle display of a tab bar in the header line.
+With prefix argument ARG, turn on if positive, otherwise off.
+Returns non-nil if the new state is enabled." t nil)
+
+(autoload (quote tabbar-local-mode) "tabbar" "\
+Toggle local display of the tab bar.
+With prefix argument ARG, turn on if positive, otherwise off.
+Returns non-nil if the new state is enabled.
+When on and tab bar global mode is on, if a buffer local value of
+`header-line-format' exists, it is saved, then the local header line
+is killed to show the tab bar.  When off, the saved local value of the
+header line is restored, hiding the tab bar." t nil)
+
 ;;;***
 
 ;;;### (autoloads (table-version table-release table-capture table-delete-column
@@ -1098,7 +1564,7 @@ Ask the system apropos command for man-pages matching QUERY." t nil)
 ;;;;;;  table-recognize table-insert-row-column table-insert-column
 ;;;;;;  table-insert-row table-insert table-point-left-cell-hook
 ;;;;;;  table-point-entered-cell-hook table-load-hook table-cell-map-hook)
-;;;;;;  "table" "table.el" (16391 1481))
+;;;;;;  "table" "table.el" (17246 57581))
 ;;; Generated autoloads from table.el
 
 (defvar table-cell-map-hook nil "\
@@ -1618,8 +2084,8 @@ Show version number of table package." t nil)
 
 ;;;***
 
-;;;### (autoloads (tail-command tail-file) "tail" "tail.el" (16262
-;;;;;;  3977))
+;;;### (autoloads (tail-command tail-file) "tail" "tail.el" (16269
+;;;;;;  21296))
 ;;; Generated autoloads from tail.el
 
 (autoload (quote tail-file) "tail" "\
@@ -1633,7 +2099,7 @@ It is also called by `tail-file'" t nil)
 
 ;;;***
 
-;;;### (autoloads (trivial-cite) "tc" "tc.el" (16295 5169))
+;;;### (autoloads (trivial-cite) "tc" "tc.el" (16295 49414))
 ;;; Generated autoloads from tc.el
 
 (autoload (quote trivial-cite) "tc" "\
@@ -1679,7 +2145,16 @@ If not, query for text to insert in bubble." t nil)
 
 ;;;***
 
-;;;### (autoloads (tld) "tld" "tld.el" (16259 18884))
+;;;### (autoloads (tlc-mode) "tlc" "tlc.el" (17221 29124))
+;;; Generated autoloads from tlc.el
+
+(autoload (quote tlc-mode) "tlc" "\
+Major mode for editing Tlc files, or files found in tlc directories." t nil)
+(add-to-list 'auto-mode-alist '("\\.tlc$" .tlc-mode))
+
+;;;***
+
+;;;### (autoloads (tld) "tld" "tld.el" (17199 13164))
 ;;; Generated autoloads from tld.el
 
 (autoload (quote tld) "tld" "\
@@ -1704,7 +2179,7 @@ If called with a prefix argument, prompt for a specific hack to run." t nil)
 
 ;;;***
 
-;;;### (autoloads (underhat-region) "under" "under.el" (16262 60507))
+;;;### (autoloads (underhat-region) "under" "under.el" (16269 21249))
 ;;; Generated autoloads from under.el
 
 (autoload (quote underhat-region) "under" "\
